Subject: [PATCH] Ispell: Harmonize "personal dictionary" terminology
From: Rudolf Adamkovič <[email-masked]>
To: [email-masked]
Date: Fri, 24 Jan 2025 11:04:57 +0100
List-Id: <debbugs-submit.debbugs.gnu.org>

Tags: patch

See the attached patch for details.

In GNU Emacs 31.0.50 (build 1, aarch64-apple-darwin24.2.0, NS
 appkit-2575.30 Version 15.2 (Build 24C101)) of 2025-01-23 built on
 Rudolfs-MacBook-Air.local
Repository revision: ed5067e689a5e38795d5c27c5a688886d259a298
Repository branch: master
Windowing system distributor 'Apple', version 10.3.2575
System Description:  macOS 15.2

Configured using:
 'configure --with-json --with-tree-sitter --with-sqlite3
 --with-native-compilation=aot'

From 4389e752227d7f049beb546397b91c56ab146608 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Rudolf=20Adamkovi=C4=8D?= <[email-masked]>
Date: Fri, 24 Jan 2025 10:52:14 +0100
Subject: [PATCH] Ispell: Harmonize "personal dictionary" terminology

* lisp/textmodes/ispell.el (ispell-command-loop, ispell-help): Stop
confusing users by using two terms for the same concept: "private
dictionary" and "personal dictionary".  For instance, if the user types
`M-$' followed by `i' to insert a word "... into *private* dictionary",
Emacs asks the user about "*personal* dictionary" modification and
saving.
---
 lisp/textmodes/ispell.el | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/lisp/textmodes/ispell.el b/lisp/textmodes/ispell.el
index d795589cb2c..b0f4e416a6e 100644
--- a/lisp/textmodes/ispell.el
+++ b/lisp/textmodes/ispell.el
@@ -56,7 +56,7 @@
 ;; Commands in ispell-region:
 ;; Character replacement: Replace word with choice.  May query-replace.
 ;; ` ': Accept word this time.
 ;; `i': Accept word and insert into private dictionary.
 ;; `a': Accept word for this session.
 ;; `A': Accept word and place in buffer-local dictionary.
 ;; `r': Replace word with typed-in value.  Rechecked.
@@ -2193,7 +2193,7 @@ ispell-command-loop
 	      (insert (car guess) "    ")
 	      (setq guess (cdr guess)))
 	    (insert (substitute-command-keys
-		     "\nUse option `i' to accept this spelling and put it in your private dictionary.\n"))))
+		     "\nUse option `i' to accept this spelling and put it in your personal dictionary.\n"))))
       (while choices
 	(when (> (+ 7 (current-column)
 		    (length (car choices))
@@ -2448,7 +2448,7 @@ ispell-help
 
 \\`0'..\\`9'  Replace the word with a digit offered in the *Choices* buffer.
 \\`SPC' Accept word this time.
-\\`i'   Accept word and insert into private dictionary.
+\\`i'   Accept word and insert into personal dictionary.
 \\`a'   Accept word for this session.
 \\`A'   Accept word and place in `buffer-local dictionary'.
 \\`r'   Replace word with typed-in value.  Rechecked.
@@ -2482,7 +2482,7 @@ ispell-help
 
 \\`0'..\\`9'  Replace the word with a digit offered in the *Choices* buffer.
 \\`SPC'   Accept word this time.
-\\`i'     Accept word and insert into private dictionary.
+\\`i'     Accept word and insert into personal dictionary.
 \\`a'     Accept word for this session.
 \\`A'     Accept word and place in `buffer-local dictionary'.
 \\`r'     Replace word with typed-in value.  Rechecked.
@@ -2502,7 +2502,7 @@ ispell-help

     (let ((help-1 (concat "[r/R]eplace word; [a/A]ccept for this session; "
-			  "[i]nsert into private dictionary"))
+			  "[i]nsert into personal dictionary"))
 	  (help-2 (concat "[l]ook a word up in alternate dictionary;  "
 			  "e[x/X]it;  [q]uit session"))
 	  (help-3 (concat "[u]ncapitalized insert into dict.  "
@@ -56,7 +56,7 @@
 ;; Character replacement: Replace word with choice.  May query-replace.
 ;; ` ': Accept word this time.
-;; `i': Accept word and insert into private dictionary.
+;; `i': Accept word and insert into personal dictionary.
 ;; `a': Accept word for this session.
 ;; `A': Accept word and place in buffer-local dictionary.
-- 
2.39.5 (Apple Git-154)

-- 
"The power of mathematics rests on its evasion of all unnecessary thought."
--- Ernst Mach, 1838-1916

Rudolf Adamkovič <[email-masked]> [he/him]
http://adamkovic.org